==> cgal-5.5.2-1-any.pkg.tar.xz: usr/include/CGAL/Intersections_3/internal/Plane_3_Triangle_3_do_intersect.h <==
// Copyright (c) 2003  INRIA Sophia-Antipolis (France).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org)
//
// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Intersections_3/include/CGAL/Intersections_3/internal/Plane_3_Triangle_3_do_intersect.h $
// $Id: Plane_3_Triangle_3_do_intersect.h c2d1adf 2021-06-23T17:34:48+02:00 Mael Rouxel-Labbé
// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
//
//
// Author(s)     : Philippe Guigue

#ifndef CGAL_INTERNAL_INTERSECTIONS_PLANE_3_TRIANGLE_3_DO_INTERSECT_H
#define CGAL_INTERNAL_INTERSECTIONS_PLANE_3_TRIANGLE_3_DO_INTERSECT_H

#include <CGAL/enum.h>
#include <CGAL/kernel_assertions.h>

namespace CGAL {
namespace Intersections {
namespace internal {

template <class K>
bool do_intersect(const typename K::Triangle_3& t,
                  const typename K::Plane_3& h,
                  const K& k)
{
  CGAL_kernel_precondition(!k.is_degenerate_3_object()(t));
  CGAL_kernel_precondition(!k.is_degenerate_3_object()(h));

  typename K::Construct_vertex_3 vertex_on = k.construct_vertex_3_object();
  typename K::Oriented_side_3 oriented_side = k.oriented_side_3_object();

  switch(oriented_side(h,vertex_on(t,0)))
  {
  case ON_POSITIVE_SIDE:
    return (oriented_side(h,vertex_on(t,1)) != ON_POSITIVE_SIDE) ||
           (oriented_side(h,vertex_on(t,2)) != ON_POSITIVE_SIDE);
  case ON_NEGATIVE_SIDE:
    return (oriented_side(h,vertex_on(t,1)) != ON_NEGATIVE_SIDE) ||
           (oriented_side(h,vertex_on(t,2)) != ON_NEGATIVE_SIDE);
  case ON_ORIENTED_BOUNDARY:
    return true;
  default:// should not happen.
    CGAL_kernel_assertion(false);
    return false;
  }
}

template <class K>
inline
bool do_intersect(const typename K::Plane_3& h,
                  const typename K::Triangle_3& t,
                  const K& k)
{
  return do_intersect(t, h, k);
}

} // namespace internal
} // namespace Intersections
} // namespace CGAL

#endif // CGAL_INTERNAL_INTERSECTIONS_PLANE_3_TRIANGLE_3_DO_INTERSECT_H

==> cgal-6.0.1-2-any.pkg.tar.xz: usr/include/CGAL/Intersections_3/internal/Plane_3_Triangle_3_do_intersect.h <==
// Copyright (c) 2003  INRIA Sophia-Antipolis (France).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org)
//
// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_3/include/CGAL/Intersections_3/internal/Plane_3_Triangle_3_do_intersect.h $
// $Id: include/CGAL/Intersections_3/internal/Plane_3_Triangle_3_do_intersect.h 50cfbde3b84 $
// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
//
//
// Author(s)     : Philippe Guigue

#ifndef CGAL_INTERNAL_INTERSECTIONS_PLANE_3_TRIANGLE_3_DO_INTERSECT_H
#define CGAL_INTERNAL_INTERSECTIONS_PLANE_3_TRIANGLE_3_DO_INTERSECT_H

#include <CGAL/enum.h>
#include <CGAL/kernel_assertions.h>

namespace CGAL {
namespace Intersections {
namespace internal {

template <class K>
typename K::Boolean
do_intersect(const typename K::Triangle_3& t,
             const typename K::Plane_3& h,
             const K& k)
{
  CGAL_kernel_precondition(!k.is_degenerate_3_object()(t));
  CGAL_kernel_precondition(!k.is_degenerate_3_object()(h));

  typename K::Construct_vertex_3 vertex_on = k.construct_vertex_3_object();
  typename K::Oriented_side_3 oriented_side = k.oriented_side_3_object();

  switch(oriented_side(h,vertex_on(t,0)))
  {
  case ON_POSITIVE_SIDE:
    return (oriented_side(h,vertex_on(t,1)) != ON_POSITIVE_SIDE) ||
           (oriented_side(h,vertex_on(t,2)) != ON_POSITIVE_SIDE);
  case ON_NEGATIVE_SIDE:
    return (oriented_side(h,vertex_on(t,1)) != ON_NEGATIVE_SIDE) ||
           (oriented_side(h,vertex_on(t,2)) != ON_NEGATIVE_SIDE);
  case ON_ORIENTED_BOUNDARY:
    return true;
  default:// should not happen.
    CGAL_kernel_assertion(false);
    return false;
  }
}

template <class K>
inline
typename K::Boolean
do_intersect(const typename K::Plane_3& h,
             const typename K::Triangle_3& t,
             const K& k)
{
  return do_intersect(t, h, k);
}

} // namespace internal
} // namespace Intersections
} // namespace CGAL

#endif // CGAL_INTERNAL_INTERSECTIONS_PLANE_3_TRIANGLE_3_DO_INTERSECT_H
